# jsonschema-referencing

An implementation-agnostic JSON reference resolution library for Rust.

## Features and Design

- Eagerly resolves all external references
- Does not support on-demand resolving of external references

## Acknowledgements

This crate is heavily inspired by the Python [`referencing`](https://github.com/python-jsonschema/referencing) package. We extend our gratitude to its authors for their excellent work and design.

